==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebDockManagerPointDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescription } from "./WebDockManagerPointDescription";
/**
 * @hidden
 */
export let WebDockManagerPointDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockManagerPointDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockManagerPointDescriptionMetadata.a == null) {
                WebDockManagerPointDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockManagerPointDescriptionMetadata.c(WebDockManagerPointDescriptionMetadata.a);
            }
            if (a.j(WebDockManagerPointDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDockManagerPointDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockManagerPoint");
            a.item("X", "Number:double");
            a.item("Y", "Number:double");
        }
        static d(a) {
            WebDockManagerPointDescriptionMetadata.b(a);
            a.aa("WebDockManagerPoint", () => new WebDockManagerPointDescription());
            a.z("WebDockManagerPoint", WebDockManagerPointDescriptionMetadata.a);
        }
    }
    WebDockManagerPointDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockManagerPointDescriptionMetadata, 'WebDockManagerPointDescriptionMetadata');
    WebDockManagerPointDescriptionMetadata.a = null;
    return WebDockManagerPointDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebDockManagerPointDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescription } from "./WebDockManagerPointDescription";
/**
 * @hidden
 */
export let WebDockManagerPointDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockManagerPointDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockManagerPointDescriptionMetadata.a == null) {
                WebDockManagerPointDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockManagerPointDescriptionMetadata.c(WebDockManagerPointDescriptionMetadata.a);
            }
            if (a.k(WebDockManagerPointDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDockManagerPointDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockManagerPoint");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("X", "Number:double");
            a.item("Y", "Number:double");
        }
        static d(a) {
            WebDockManagerPointDescriptionMetadata.b(a);
            a.ac("WebDockManagerPoint", () => new WebDockManagerPointDescription());
            a.ab("WebDockManagerPoint", WebDockManagerPointDescriptionMetadata.a);
        }
    }
    WebDockManagerPointDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockManagerPointDescriptionMetadata, 'WebDockManagerPointDescriptionMetadata');
    WebDockManagerPointDescriptionMetadata.a = null;
    return WebDockManagerPointDescriptionMetadata;
})();
